@@ -3,6 +3,7 @@
 #' 
 #' @param prec matrix or data.frame containing the original precipitation data. Each column represents one station. The names of columns have to be names of the stations.
 #' @param sts matrix or data.frame. A column "ID" (unique ID of stations) is required. The rest of the columns (all of them) will act as predictors of the model.
+#' @param model_fun function. A function that integrates the statistical hybrid model (classification and regression).
 #' @param crs character. Coordinates system in EPSG format (e.g.: "EPSG:4326").
 #' @param coords vector of two character elements. Names of the fields in "sts" containing longitude and latitude.
 #' @param coords_as_preds logical. If TRUE (default), "coords" are also taken as predictors.
@@ -14,7 +15,7 @@
 #' @param qc5 numeric vector of length 2. Thresholds of dry probability (0 to 1) and magnitude (in the units of input precipitation data) from which a observation higher than a specific value (also in the original units), in comparison with its estimate, should be deleted. Default is c(0.01, 0.1, 5). 
 #' @noRd
 
-qcFirst <- function(x, it, sts, neibs, coords_as_preds = TRUE, coords, crs, qc = 'all', qc3 = 10, qc4 = c(0.99, 5), qc5 = c(0.01, 0.1, 5), thres = NA) {
+qcFirst <- function(x, it, sts, model_fun, neibs, coords_as_preds = TRUE, coords, crs, qc = 'all', qc3 = 10, qc4 = c(0.99, 5), qc5 = c(0.01, 0.1, 5), thres = NA) {
   
   
   n <- names(sts)
@@ -29,7 +30,8 @@ qcFirst <- function(x, it, sts, neibs, coords_as_preds = TRUE, coords, crs, qc =
   
   n <- names(sts)
   if(!coords_as_preds) n <- n[-match(coords,names(sts))]
-  covars <- paste(n, collapse='+') # predictors
+  # covars <- paste(n, collapse='+') # predictors
+  covars <- n
   
   if(length(qc)==1){
     if(qc == "all") qc <- as.character(paste0(1:5))
@@ -44,7 +46,7 @@ qcFirst <- function(x, it, sts, neibs, coords_as_preds = TRUE, coords, crs, qc =
     
       #subset dataset based on available data
       sub <- data.frame(sts[w,],val = x[w])
-      sub <- vect(sub, geom = coords,crs = crs, keepgeom = TRUE)
+      sub <- terra::vect(sub, geom = coords,crs = crs, keepgeom = TRUE)
       
    if (it > 1 & detect == 0) {#if no more suspects ends
       return(c(x, 0))
@@ -68,7 +70,7 @@ qcFirst <- function(x, it, sts, neibs, coords_as_preds = TRUE, coords, crs, qc =
             if(length(dd)<neibs){
               # message(paste0("Not enough observations within radius"))
               # pb <- p <- NA
-              return(c(x,0))
+              return(c(x, 0))
             } else{
           ref <- ref[match(sort(dd)[1:neibs],dd)]
           
@@ -87,33 +89,12 @@ qcFirst <- function(x, it, sts, neibs, coords_as_preds = TRUE, coords, crs, qc =
                 pb <- 1
                 p <- ref$val[1]
               } else{
-                # probability of ocurrence prediction
-                rr <- as.data.frame(ref)
-                rr$val[rr$val > 0] <- 1
+
+                out <- model_fun(ref = ref, can = can, covars = covars)
+                out <- round(out, 3)
+                pb <- out[1]
+                p <- out[2]
                 
-                
-                  f <- as.formula(paste0('val ~ ',covars))
-                fmtb <- suppressWarnings(
-                  glm(f,family = binomial(),data = rr)
-                  )
-                
-                pb <- round(predict(fmtb, newdata = as.data.frame(can), 
-                              type = "response"),3)
-                
-                #amount prediction
-                #rescaling
-                rr <- as.data.frame(ref)
-                MINc <- min(rr$val) - (as.numeric(quantile(rr$val, 0.50)) - as.numeric(quantile(rr$val, 0.25)))
-                MINc <- ifelse(MINc<0,0,MINc)
-                MAXc <- max(rr$val) + (as.numeric(quantile(rr$val, 0.75))-as.numeric(quantile(rr$val, 0.50)))
-                RANGE <- as.numeric(MAXc - MINc)
-                rr$val <- (rr$val - MINc) / RANGE
-                
-                fmt <- suppressWarnings(
-                  glm(f,family = quasibinomial(),data = rr)
-                )
-                p <- predict(fmt, newdata = as.data.frame(can),type = "response")
-                p <- round((p * RANGE) + MINc, 3)
               }
             }
           }
